/*
 * Tuxcall -- Call waiting detector for Linux
 * Copyright (C) 2001-2002 Angel Luis Jimenez Martinez
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#   include <config.h>
#endif

#include <intl.h>
#include <stdio.h>
#include <fcntl.h>
#include <stdlib.h>
#include <sys/ioctl.h>
#include <linux/soundcard.h>

/*
 * Opens DSP and init it with the format, channels & speed of sampling 
 * On succes return file descriptor 
 * On failure return -1
 */ 
int initDSP( char * dev, int format, int channels, int speed )
{
    int reqFormat= format, dsp;

    if ( (dsp= open(dev, O_RDONLY)) == -1 )
    {                       
        perror( dev );
        return -1;        
    }                   

    if ( ioctl(dsp, SNDCTL_DSP_SETFMT, &format) == -1 )
    {
        perror("SNDCTL_DSP_SETFMT");
        return -1;        
    }

    if ( format != reqFormat ) 
    {
        fprintf(stderr, _("Can't set requested format\n") );
        return -1;        
    }

    if ( ioctl(dsp, SNDCTL_DSP_CHANNELS, &channels) == -1 ) 
    {
        perror("SNDCTL_DSP_CHANNELS");
        return -1;        
    }

    if ( ioctl(dsp, SNDCTL_DSP_SPEED, &speed) == -1 ) 
    {
        perror("SNDCTL_DSP_SPEED");
        return -1;        
    }

    return dsp;
}

