/*
 * Tuxcall -- Call waiting detector for Linux
 * Copyright (C) 2001-2002 Angel Luis Jimenez Martinez
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#   include <config.h>
#endif

#include <stdio.h>
#include "vec.h"

/*
 * Inits vec (size len) to value zero
 */
void zero( float * vec, long len )
{
    long i;

    for( i=0; i<len; i++ )
        vec[i]= 0;
}

/*
 * Inits vec (size len) to value zero (signed short)
 */
void zeroSS( signed short * vec, long len )
{
    long i;

    for( i=0; i<len; i++ )
        vec[i]= 0;
}

/*
 * Read values from file to vec
 * file's lines have this format  
 *      index\tvalue
 */
void readVec( FILE * file, signed short * vec )
{
    long i= 0, index;

    while( !feof(file) ) 
        fscanf( file, "%ld\t%hd\n", &index, &vec[i++] );
}

/*
 * Write float array vec (size len) to file using this format:
 *      index\tvalue
 */
void writeVec( FILE * file, float * vec, long lenVec )
{
    long i;

    for( i=0; i<lenVec; i++ )
        fprintf( file, "%ld\t%f\n", i, vec[i] );
}

/*
 * Write float array vec (size len) to file using this format:
 *      index\tvalue
 * 
 * (uses n as first index)
 */
void writeVecN( FILE * file, float * vec, long lenVec, long n )
{
    long i;

    for( i=0; i<lenVec; i++ )
        fprintf( file, "%ld\t%f\n", n+i, vec[i] );
}


/* 
 * Write float vec (size len) to stdout using this format:
 *       index\tvalue 
 */
void printVec( float * vec, long len )
{
    long i;

    for( i=0; i<len; i++ )
        printf( "%ld\t%f\n", i, vec[i] );
}

/* 
 * Write signed short vec (size len) to stdout using this format:
 *       index\tvalue 
 */
void printVecSS( signed short * vec, long len )
{
    long i;

    for( i=0; i<len; i++ )
        printf( "%ld\t%hd\n", i, vec[i] );
}

